@@ -12,13 +12,13 @@
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License
-   version 2.1 as published by the Free Software Foundation, with the
+   version 3 as published by the Free Software Foundation, with the
    special exception on linking described in file LICENSE.
 
    This library is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the file
-   LICENSE for more details.
+   LICENSE.txt for more details.
 *)
 
 open Printf
@@ -181,7 +181,7 @@ type printer = {
 let print_run out ?(min_count=4L) ?(min_cpu=0.4) ~style ?fwidth ?fdigits b =
   out.print_indent(to_string ~style ?fwidth ?fdigits b ^ "\n");
   if b.iters < min_count || cpu_all b < min_cpu
-    || (b.wall < 1. && b.iters < 1000L)
+     || (b.wall < 1. && b.iters < 1000L)
   then out.print_indent "(warning: too few iterations for a reliable count)\n"
 
 
@@ -189,10 +189,12 @@ let latency n out ?min_count ?min_cpu ~style ?fwidth ?fdigits
     ~repeat name f x =
   let rec loop nrep acc =
     if nrep < 1 then acc
-    else
+    else (
+      Gc.compact(); (* Reclaim memory to avoid undue GC during the test. *)
       let bm, _ = timeit n f x in
       print_run out ?min_count ?min_cpu ~style ?fwidth ?fdigits bm;
-      loop (nrep - 1) (bm :: acc) in
+      loop (nrep - 1) (bm :: acc)
+    ) in
   loop repeat []
 
 
@@ -219,7 +221,8 @@ let throughput tmin out ?min_count ?min_cpu ~style ?fwidth ?fdigits
       run_test nmin (max nmin n) bm total_wall in
   (* Repeat the test [nrep] times and return the list of results. *)
   let rec repeat_test nrep acc nmin niter wall_estim =
-    if nrep < 1 then acc else
+    if nrep < 1 then acc else (
+      Gc.compact(); (* Reclaim memory to avoid undue GC during the test. *)
       let bm, wall = run_test nmin niter null_t 0. in
       let wall_estim =
         if wall > wall_estim +. 60. then (
@@ -228,7 +231,8 @@ let throughput tmin out ?min_count ?min_cpu ~style ?fwidth ?fdigits
           wall
         )
         else wall_estim in
-      repeat_test (nrep - 1) (bm :: acc) nmin niter wall_estim in
+      repeat_test (nrep - 1) (bm :: acc) nmin niter wall_estim
+    ) in
   (* Estimate number of iter > [nmin] to have a running time >=
      [tmin].  The initial estimate is [n] running [tn] secs.  Linear
      estimates bear a 5% fudge to improve the overall responsiveness. *)
@@ -236,14 +240,16 @@ let throughput tmin out ?min_count ?min_cpu ~style ?fwidth ?fdigits
   let rec estimate_niter nmin n tn wall =
     if tn >= tpra then
       (* FIXME: *)
-      let niter = Int64.of_float(Int64.to_float n *. (1.05 *. tmin /. tn)) (* lin estim *) in
+      (* lin estim *)
+      let niter = Int64.of_float(Int64.to_float n *. (1.05 *. tmin /. tn)) in
       let wall_estim = wall *. (1.05 *. tmin /. tn) in
       if wall_estim >= 60. then
         out.print_indent("(Estimated time for each run: "
-                          ^ (string_of_time wall_estim) ^ ")\n");
+                         ^ (string_of_time wall_estim) ^ ")\n");
       repeat_test repeat [] nmin (max nmin niter) wall_estim
     else
-      let new_n = Int64.of_float(Int64.to_float n *. 1.05 *. tpra /. tn) (* lin estim *) in
+      (* lin estim *)
+      let new_n = Int64.of_float(Int64.to_float n *. 1.05 *. tpra /. tn) in
       let new_bn, new_wall = timeit new_n f x in
       let new_tn = cpu_process new_bn in
       let n = (* make sure we make progress *)
@@ -252,28 +258,35 @@ let throughput tmin out ?min_count ?min_cpu ~style ?fwidth ?fdigits
       estimate_niter nmin n new_tn new_wall in
   (* Determine the minimum number of iterations to run >= 0.1 sec
      (whatever [tmin]).  Inform the user if it takes too long. *)
-  let rec min_iter n ~takes_long total_wall =
+  let rec min_iter n ~takes_long:previous_took_long total_wall =
     if n <= 0L then
       failwith "throughput: number of iterations too large for Int64.t storage";
     let bm, wall = timeit n f x in
     let tn = cpu_process bm in
     let total_wall = total_wall +. wall in
     if tn < 0.1 then (
-      let takes_long =
-        if total_wall >= 30. then (
-          if takes_long then out.print "." else
-            out.print_indent("(Determining how many runs to perform, \
-		please be patient...");
-          true
+      let takes_long = total_wall >= 30. in
+      if takes_long then (
+        if total_wall >= 120. then (
+          out.print " canceled)\n";
+          failwith(sprintf "Benchmark.throughputN: wall time is %g while \
+            CPU time is %g.  Do you use \"sleep\"?" total_wall tn)
         )
-        else false in
-      min_iter (Int64.shift_left n 1) (* 2*n *) ~takes_long total_wall
+        else if previous_took_long then out.print "." else
+          out.print_indent("(Determining how many runs to perform, \
+            please be patient...");
+        );
+      let twice_n = Int64.shift_left n 1 in
+      min_iter twice_n ~takes_long total_wall
     )
     else (
-      if takes_long then out.print ")\n";
+      if previous_took_long then out.print ")\n";
       if tn < tmin then estimate_niter n n tn wall (* tn > 0.1 *)
-      else  (* minimal [n] good for [tmin] *)
+      else ( (* minimal [n] good for [tmin], use the above measurement
+                for the first run. *)
+        print_run out ?min_count ?min_cpu ~style ?fwidth ?fdigits bm;
         repeat_test (repeat - 1) [bm] n n wall
+      )
     ) in
   min_iter 1L ~takes_long:false 0.
 
@@ -302,7 +315,7 @@ let testN ~test default_f_name  ?min_count ?min_cpu ~style
     let out = if style = Nil then null_printer
               else make_printer (length_name + 2) in
     let bm = test out ?min_count ?min_cpu ~style ?fwidth ?fdigits
-      ~repeat name f x in
+                  ~repeat name f x in
     (name, bm) in
   List.map result_of funs
 
